CARP Apps Sampling Package

CARP pub package GitHub MIT License Documentation arXiv Discord

This library contains a sampling package for app-related sampling to work with the carp_mobile_sensing framework. This packages supports sampling of the following Measure types:

  • dk.cachet.carp.apps - a list of installed apps on the phone.
  • dk.cachet.carp.appusage - a log of app usage activity.

These measures are only available on Android.

See the CAMS documentation site for further documentation. See the CARP Mobile Sensing App for an example of how to build a mobile sensing app in Flutter.

For Flutter plugins for other CARP products, see CARP Mobile Sensing in Flutter.

If you're interested in writing your own sampling packages for CARP, see the description on how to extend CARP Mobile Sensing.

Installing

To use this package, add the following to your pubspec.yaml file. Note that this package only works together with carp_mobile_sensing.

dependencies:
  flutter:
    sdk: flutter
  carp_core: ^latest
  carp_mobile_sensing: ^latest
  carp_apps_package: ^latest
  ...

Android Integration

Add the following to your app's AndroidManifest.xml file located in android/app/src/main such that it contains the following permission request:

<uses-permission android:name="android.permission.PACKAGE_USAGE_STATS" tools:ignore="ProtectedPermissions"/>
<uses-permission android:name="android.permission.QUERY_ALL_PACKAGES" />

Starting with Android 11, Android applications targeting API level 30, wanting to list "external" applications have to declare a new "normal" permission in their AndroidManifest.xml file called QUERY_ALL_PACKAGES.

Starting from May 5 2021, Google will mark a breaking change on how applications requesting QUERY_ALL_PACKAGES are accepted in the Google Play. Quoting from the doc:

Permitted use involves apps that must discover any and all installed apps on the device, for awareness or interoperability purposes may have eligibility for the permission. Permitted use includes; device search, antivirus apps, file managers, and browsers.

Apps granted access to this permission must comply with the User Data policies, including the Prominent Disclosure and Consent requirements, and may not extend its use to undisclosed or invalid purposes.

iOS Integration

Not supported.

Using it

To use this package, import it into your app together with the carp_mobile_sensing package:

import 'package:carp_core/carp_core.dart';
import 'package:carp_mobile_sensing/carp_mobile_sensing.dart';
import 'package:carp_apps_package/apps.dart';

Before creating a study and running it, register this package in the SamplingPackageRegistry.

SamplingPackageRegistry().register(AppsSamplingPackage());

Collection of APPS and APP_USAGE measures can be added to a study protocol like this.

// Define which devices are used for data collection
// In this case, its only this smartphone
Smartphone phone = Smartphone();
protocol.addPrimaryDevice(phone);

// Add an background task that collects the list of installed apps
// and a log of app usage activity
protocol.addTaskControl(
    ImmediateTrigger(),
    BackgroundTask(measures: [
      Measure(type: AppsSamplingPackage.APPS),
      Measure(type: AppsSamplingPackage.APP_USAGE),
    ]),
    phone);

Note that both the APPS and the APP_USAGE are one-time measures, and hence only collect a measurement once. If you want to collect app usage e.g., based on app lifecycle events, you could add this to the protocol:

// Add an background task that collects app usage activity when this app
// changes state to foreground.
protocol.addTaskControl(
  AppLifecycleTrigger({AppLifecycleState.resumed}),
  BackgroundTask(measures: [Measure(type: AppsSamplingPackage.APP_USAGE)]),
  phone,
);

Libraries

apps
A library for collecting data from apps on the phone.