AppUsage class

Holds a map of names of apps and their usage, as defined in AppUsageInfo.

Inheritance
  • Object
  • Serializable
  • Data
  • AppUsage
Annotations
  • @JsonSerializable.new(includeIfNull: false, explicitToJson: true)

Constructors

AppUsage(DateTime start, DateTime end, [Map<String, AppUsageInfo> usage = const {}])
AppUsage.fromJson(Map<String, dynamic> json)
factory

Properties

$type String?
The runtime class name (type) of this object. Used for deserialization from JSON objects.
getter/setter pairinherited
dataType → DataType
The type of this data as a DataType.
no setterinherited
end DateTime
getter/setter pair
fromJsonFunction Function
The function which can convert a JSON string to an object of this type.
no setteroverride
hashCode int
The hash code for this object.
no setterinherited
jsonType String
Return the __type to be used for JSON serialization of this class. Default is runtimeType. Only specify this if you need another type.
no setterinherited
recordId String?
Stable identifier of the source record, if available.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
start DateTime
getter/setter pair
usage Map<String, AppUsageInfo>
A map from the full package name of an app and its usage.
getter/setter pair

Methods

equivalentTo(Data other) bool
Is this data equivalent to other?
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
Return a JSON encoding of this object.
override
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited